/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * $Id: DOMStringList.java 511423 2007-02-25 03:21:05Z vgritsenko $
 */

package org.w3c.dom;

/**
 * The DOMStringList interface provides the abstraction of an ordered
 * collection of DOMString values, without defining or constraining how this
 * collection is implemented. The items in the DOMStringList are accessible
 * via an integral index, starting from 0.
 *
 * @since DOM Level 3
 * @version $Revision: 511423 $, $Date: 2007-02-24 22:21:05 -0500 (Sat, 24 Feb 2007) $
 */
public interface DOMStringList {

    /**
     * Returns the indexth item in the collection. If index is greater than or
     * equal to the number of DOMStrings in the list, this returns null.
     * @param index Index into the collection.
     * @return The DOMString at the indexth position in the DOMStringList, or
     *         null if that is not a valid index.
     */
    public String item(int index);

    /**
     * The number of DOMStrings in the list. The range of valid child node
     * indices is 0 to length-1 inclusive.
     * @return The number of DOMStrings in the list. The range of valid child
     *         node indices is 0 to length-1 inclusive.
     */
    public int getLength();

    /**
     * Test if a string is part of this DOMStringList.
     * @param str The string to look for.
     * @return true if the string has been found, false otherwise.
     */
    public boolean contains(String str);
}
