package addressbook;

/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * $Id: Action.java 511428 2007-02-25 03:30:52Z vgritsenko $
 */

import java.util.Hashtable;
import java.util.Vector;

import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.xpath.XPathAPI;
import org.apache.xpath.objects.XObject;
import org.w3c.dom.Node;
import org.xmldb.api.base.Collection;
import org.xmldb.api.base.ResourceIterator;
import org.xmldb.api.modules.XMLResource;

/**
 * Common class for the Addressbook
 */
public abstract class Action extends HttpServlet {

   // Version of the XMLDB Api that we are using
   public final static String XMLDBAPIVERSION = "1.0";

   // Singleton class used to hold connnection to database
   protected static DBConnection connection = new DBConnection();

   /**
    * Return a collection object for the addressbook
    */
   public Collection getCollection(HttpServletRequest request, HttpServletResponse response) throws javax.servlet.ServletException, java.io.IOException {
      return connection.getCollectionInstance(request, response);
   }

   /**
    * Return a vector of hashtables populated with all elements in
    * ResourceIterator
    */
   public Vector getContactVectorFromIterator(ResourceIterator results) {

      // new Vector instance to be returned
      Vector vector = new Vector();
      try {
         while (results.hasMoreResources()) {

            // Create an XObject to be used in Xpath query
            XObject xo = new XObject();
            // Create a new hastable to store into vector
            Hashtable table = new Hashtable();

            // Retrieve the next node
            XMLResource resource = (XMLResource) results.nextResource();
            Node originalnode = resource.getContentAsDOM();

            // Get the document key for this node for later use
            String dockey = resource.getDocumentId();
            table.put("dockey", dockey);

            // Use Xalan xpath parser to extract data, store into hastable
            xo = XPathAPI.eval(originalnode, "/person/fname");
            table.put("fname", xo.toString());

            xo = XPathAPI.eval(originalnode, "/person/lname");
            table.put("lname", xo.toString());

            xo = XPathAPI.eval(originalnode, "/person/phone[@type='work']");
            table.put("workphone", xo.toString());

            xo = XPathAPI.eval(originalnode, "/person/phone[@type='home']");
            table.put("homephone", xo.toString());

            xo = XPathAPI.eval(originalnode, "/person/phone[@type='cell']");
            table.put("cellphone", xo.toString());

            xo = XPathAPI.eval(originalnode, "/person/email[@type='home']");
            table.put("homeemail", xo.toString());

            xo = XPathAPI.eval(originalnode, "/person/email[@type='work']");
            table.put("workemail", xo.toString());

            xo = XPathAPI.eval(originalnode, "/person/address[@type='home']");
            table.put("homeaddress", xo.toString());

            xo = XPathAPI.eval(originalnode, "/person/address[@type='work']");
            table.put("workaddress", xo.toString());

            // Add hashtable to vector to pass on to JSP page
            vector.add(table);
         }

      }
      catch (Exception e) {
         e.printStackTrace();
      }

      return vector;
   }

   /**
    * Create a String XML document from passed in parameters
    */
   public String toXml(String fname, String lname, String workphone,
         String homephone, String cellphone, String homeemail, String workemail,
         String homeaddress, String workaddress) {

      String ourdoc;

      // Build up the string to represent our document
      ourdoc = "<person>";
      ourdoc = ourdoc + "<fname>" + fname + "</fname>";
      ourdoc = ourdoc + "<lname>" + lname + "</lname>";
      ourdoc = ourdoc + "<phone type='work'>" + workphone + "</phone>";
      ourdoc = ourdoc + "<phone type='home'>" + homephone + "</phone>";
      ourdoc = ourdoc + "<phone type='cell'>" + cellphone + "</phone>";
      ourdoc = ourdoc + "<email type='home'>" + homeemail + "</email>";
      ourdoc = ourdoc + "<email type='work'>" + workemail + "</email>";
      ourdoc = ourdoc + "<address type='home'>" + homeaddress + "</address>";
      ourdoc = ourdoc + "<address type='work'>" + workaddress + "</address>";
      ourdoc = ourdoc + "</person>";

      // Return the created XML string
      return ourdoc;
   }

}

