package org.apache.xindice.examples;

/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * $Id: AbstractExample.java 511428 2007-02-25 03:30:52Z vgritsenko $
 */

import org.apache.xindice.util.XindiceException;
import org.xmldb.api.DatabaseManager;
import org.xmldb.api.base.Collection;
import org.xmldb.api.base.Database;
import org.xmldb.api.base.XMLDBException;

/**
 * Simple XML:DB API Example 
 */
public abstract class AbstractExample {

    private static boolean alreadyInitialized = false;

    protected static void ensureInitialized()
        throws ClassNotFoundException, InstantiationException, IllegalAccessException,
               XMLDBException {

        if (alreadyInitialized) {
            return;
        }

        String driver = "org.apache.xindice.client.xmldb.DatabaseImpl";
        Class driverClass = Class.forName(driver);
        Database database = (Database) driverClass.newInstance();
        DatabaseManager.registerDatabase(database);
        alreadyInitialized = true;
    }

    protected static Collection getCollection(String collectionUri)
        throws ClassNotFoundException, InstantiationException, IllegalAccessException,
               XMLDBException, XindiceException {

        ensureInitialized();
        Collection collection = DatabaseManager.getCollection(collectionUri);
        if (collection == null) {
            throw new XindiceException("DatabaseManager.getCollection(" + collectionUri + ") returned null.");
        }

        return collection;
    }
}
