/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * $Id: CommonConfigurable.java 564214 2007-08-09 14:23:06Z vgritsenko $
 */

package org.apache.xindice.client.xmldb;

import org.xmldb.api.base.Configurable;
import org.xmldb.api.base.XMLDBException;

import java.util.HashMap;

/**
 * Base class to handle property management within the API implementation.
 *
 * @version $Revision: 564214 $, $Date: 2007-08-09 10:23:06 -0400 (Thu, 09 Aug 2007) $
 */
public abstract class CommonConfigurable implements Configurable {

    private HashMap config;

    /**
     * Constructor for the CommonConfigurable object
     */
    public CommonConfigurable() {
        config = new HashMap();
    }

    /**
     * Constructor for the CommonConfigurable object
     *
     * @param commonConfigurable from which the initial properties for this
     *        object are copied.
     */
    public CommonConfigurable(CommonConfigurable commonConfigurable) {
        config = new HashMap(commonConfigurable.config);
    }

    /**
     * Sets a property value. If the property doesn't exist it is created, if it
     * does exist it is overwritten.
     *
     * @param name The Property name
     * @param value The new Property value
     * @throws XMLDBException never
     */
    public void setProperty(String name, String value) throws XMLDBException {
        config.put(name, value);
    }

    /**
     * Gets the property value associated with name
     *
     * @param name The name of the property to retrieve.
     * @return The Property value
     * @throws XMLDBException never
     */
    public String getProperty(String name) throws XMLDBException {
        return (String) config.get(name);
    }
}
