/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * $Id: FaultCodes.java 564427 2007-08-09 23:45:48Z vgritsenko $
 */

package org.apache.xindice.core;

import org.xmldb.api.base.ErrorCodes;
import org.xmldb.api.base.XMLDBException;

import java.util.HashMap;
import java.util.Map;

/**
 * FaultCodes defines the Xindice specific fault codes and associated error
 * messages.
 *
 * @version $Revision: 564427 $, $Date: 2007-08-09 19:45:48 -0400 (Thu, 09 Aug 2007) $
 */
public abstract class FaultCodes {

    /**
     * Defines maximum possible fault code
     */
    public static final int MAX_CODE  = 10000;

    private static final Map faultMessages = new HashMap();

    private static final Map faultCodesToErrorCodesMap = new HashMap();

    public static final int GEN  =    0;
    public static final int OBJ  =  100;
    public static final int COL  =  200;
    public static final int IDX  =  300;
    public static final int TRX  =  400;
    public static final int DBE  =  500;
    public static final int QRY  =  600;
    public static final int SEC  =  700;
    public static final int URI  =  800;
    public static final int JAVA = 2000;

    public static final int GEN_UNKNOWN        =  0;
    public static final int GEN_GENERAL_ERROR  = 40;
    public static final int GEN_CRITICAL_ERROR = 70;
    public static final int GEN_FATAL_ERROR    = 90;

    public static final int COL_COLLECTION_NOT_FOUND = 200;
    public static final int COL_DOCUMENT_NOT_FOUND   = 201;
    public static final int COL_DUPLICATE_COLLECTION = 240;
    public static final int COL_NULL_RESULT          = 241;
    public static final int COL_NO_FILER             = 242;
    public static final int COL_NO_INDEXMANAGER      = 242;
    public static final int COL_DOCUMENT_MALFORMED   = 243;
    public static final int COL_CANNOT_STORE         = 244;
    public static final int COL_CANNOT_RETRIEVE      = 245;
    public static final int COL_COLLECTION_READ_ONLY = 246;
    public static final int COL_COLLECTION_CLOSED    = 247;
    public static final int COL_DUPLICATE_RESOURCE   = 248;
    public static final int COL_CANNOT_CREATE        = 270;
    public static final int COL_CANNOT_DROP          = 271;
    public static final int COL_INVALID_RESULT       = 277;

    public static final int IDX_VALUE_NOT_FOUND      = 300;
    public static final int IDX_INDEX_NOT_FOUND      = 301;
    public static final int IDX_MATCHES_NOT_FOUND    = 340;
    public static final int IDX_DUPLICATE_INDEX      = 341;
    public static final int IDX_NOT_SUPPORTED        = 370;
    public static final int IDX_STYLE_NOT_FOUND      = 371;
    public static final int IDX_CORRUPTED            = 372;
    public static final int IDX_CANNOT_CREATE        = 373;

    public static final int TRX_DOC_LOCKED           = 400;
    public static final int TRX_NO_CONTEXT           = 440;
    public static final int TRX_NOT_ACTIVE           = 441;
    public static final int TRX_NOT_SUPPORTED        = 470;

    public static final int DBE_NO_PARENT            = 500;
    public static final int DBE_CANNOT_DROP          = 570;
    public static final int DBE_CANNOT_CREATE        = 571;
    public static final int DBE_CANNOT_READ          = 572;

    public static final int QRY_NULL_RESULT          = 600;
    public static final int QRY_COMPILATION_ERROR    = 640;
    public static final int QRY_PROCESSING_ERROR     = 641;
    public static final int QRY_NOT_SUPPORTED        = 670;
    public static final int QRY_STYLE_NOT_FOUND      = 671;

    public static final int SEC_INVALID_USER         = 770;
    public static final int SEC_INVALID_GROUP        = 771;
    public static final int SEC_INVALID_ACCESS       = 772;
    public static final int SEC_INVALID_CREDENTIALS  = 773;

    public static final int URI_EMPTY                = 800;
    public static final int URI_NULL                 = 801;
    public static final int URI_PARSE_ERROR          = 820;

    public static final int JAVA_RUNTIME_ERROR       = 2070;


    private FaultCodes() {
    }

    static {
        // General errors 0 series
        putCodeMessage(GEN_UNKNOWN, "Unknown");
        putCodeMessage(GEN_GENERAL_ERROR, "General Error");
        putCodeMessage(GEN_CRITICAL_ERROR, "Critical Error");
        putCodeMessage(GEN_FATAL_ERROR, "Fatal Error");

        addFaultCodeToErrorCodeMap(GEN_UNKNOWN, ErrorCodes.UNKNOWN_ERROR);
        addFaultCodeToErrorCodeMap(GEN_GENERAL_ERROR, ErrorCodes.UNKNOWN_ERROR);
        addFaultCodeToErrorCodeMap(GEN_CRITICAL_ERROR, ErrorCodes.UNKNOWN_ERROR);
        addFaultCodeToErrorCodeMap(GEN_FATAL_ERROR, ErrorCodes.UNKNOWN_ERROR);

        // Collection-related errors 200 series
        putCodeMessage(COL_COLLECTION_NOT_FOUND, "Collection Not Found");
        putCodeMessage(COL_DOCUMENT_NOT_FOUND, "Collection Document Not Found");
        putCodeMessage(COL_DUPLICATE_COLLECTION, "Collection Duplicated");
        putCodeMessage(COL_NULL_RESULT, "Collection Null Result");
        putCodeMessage(COL_NO_FILER, "Collection No Filer");
        putCodeMessage(COL_NO_INDEXMANAGER, "Collection No IndexManager");
        putCodeMessage(COL_DOCUMENT_MALFORMED, "Collection Document Malformed");
        putCodeMessage(COL_CANNOT_STORE, "Collection Cannot Store");
        putCodeMessage(COL_CANNOT_RETRIEVE, "Collection Cannot Retrieve");
        putCodeMessage(COL_COLLECTION_READ_ONLY, "Collection Read-only");
        putCodeMessage(COL_COLLECTION_CLOSED, "Collection Closed");
        putCodeMessage(COL_DUPLICATE_RESOURCE, "Resource Duplicated");
        putCodeMessage(COL_CANNOT_CREATE, "Collection Cannot Create");
        putCodeMessage(COL_CANNOT_DROP, "Collection Cannot Drop");
        putCodeMessage(COL_INVALID_RESULT, "Collection Invalid Result");

        addFaultCodeToErrorCodeMap(COL_COLLECTION_NOT_FOUND, ErrorCodes.NO_SUCH_COLLECTION);
        addFaultCodeToErrorCodeMap(COL_DOCUMENT_NOT_FOUND, ErrorCodes.NO_SUCH_RESOURCE);
        addFaultCodeToErrorCodeMap(COL_DUPLICATE_COLLECTION, ErrorCodes.INVALID_COLLECTION);
        addFaultCodeToErrorCodeMap(COL_NULL_RESULT, ErrorCodes.INVALID_COLLECTION);
        addFaultCodeToErrorCodeMap(COL_NO_FILER, ErrorCodes.INVALID_COLLECTION);
        addFaultCodeToErrorCodeMap(COL_NO_INDEXMANAGER, ErrorCodes.INVALID_COLLECTION);
        addFaultCodeToErrorCodeMap(COL_DOCUMENT_MALFORMED, ErrorCodes.INVALID_RESOURCE);
        addFaultCodeToErrorCodeMap(COL_CANNOT_STORE, ErrorCodes.VENDOR_ERROR);
        addFaultCodeToErrorCodeMap(COL_CANNOT_RETRIEVE, ErrorCodes.VENDOR_ERROR);
        addFaultCodeToErrorCodeMap(COL_COLLECTION_READ_ONLY, ErrorCodes.VENDOR_ERROR);
        addFaultCodeToErrorCodeMap(COL_COLLECTION_CLOSED, ErrorCodes.COLLECTION_CLOSED);
        addFaultCodeToErrorCodeMap(COL_CANNOT_CREATE, ErrorCodes.VENDOR_ERROR);
        addFaultCodeToErrorCodeMap(COL_CANNOT_DROP, ErrorCodes.VENDOR_ERROR);
        addFaultCodeToErrorCodeMap(COL_INVALID_RESULT, ErrorCodes.VENDOR_ERROR);

        // Index-related errors 300 series
        putCodeMessage(IDX_VALUE_NOT_FOUND, "Index Value Not Found");
        putCodeMessage(IDX_INDEX_NOT_FOUND, "Index Not Found");
        putCodeMessage(IDX_MATCHES_NOT_FOUND, "Index Matches Not Found");
        putCodeMessage(IDX_DUPLICATE_INDEX, "Index Duplicate Index");
        putCodeMessage(IDX_NOT_SUPPORTED, "Index Not Supported");
        putCodeMessage(IDX_STYLE_NOT_FOUND, "Index Style Not Found");
        putCodeMessage(IDX_CORRUPTED, "Index Corrupted");
        putCodeMessage(IDX_CANNOT_CREATE, "Index Cannot Create");

        addFaultCodeToErrorCodeMap(IDX_VALUE_NOT_FOUND, ErrorCodes.INVALID_RESOURCE);
        addFaultCodeToErrorCodeMap(IDX_INDEX_NOT_FOUND, ErrorCodes.NO_SUCH_RESOURCE);
        addFaultCodeToErrorCodeMap(IDX_MATCHES_NOT_FOUND, ErrorCodes.VENDOR_ERROR);
        addFaultCodeToErrorCodeMap(IDX_DUPLICATE_INDEX, ErrorCodes.INVALID_RESOURCE);
        addFaultCodeToErrorCodeMap(IDX_NOT_SUPPORTED, ErrorCodes.NOT_IMPLEMENTED);
        addFaultCodeToErrorCodeMap(IDX_STYLE_NOT_FOUND, ErrorCodes.NO_SUCH_RESOURCE);
        addFaultCodeToErrorCodeMap(IDX_CORRUPTED, ErrorCodes.INVALID_RESOURCE);
        addFaultCodeToErrorCodeMap(IDX_CANNOT_CREATE, ErrorCodes.VENDOR_ERROR);

        // Transaction-related errors 400 series
        putCodeMessage(TRX_DOC_LOCKED, "Transaction Document Locked");
        putCodeMessage(TRX_NO_CONTEXT, "Transaction No Context");
        putCodeMessage(TRX_NOT_ACTIVE, "Transaction Not Active");
        putCodeMessage(TRX_NOT_SUPPORTED, "Transaction Not Supported");

        addFaultCodeToErrorCodeMap(TRX_DOC_LOCKED, ErrorCodes.VENDOR_ERROR);
        addFaultCodeToErrorCodeMap(TRX_NO_CONTEXT, ErrorCodes.INVALID_RESOURCE);
        addFaultCodeToErrorCodeMap(TRX_NOT_ACTIVE, ErrorCodes.VENDOR_ERROR);
        addFaultCodeToErrorCodeMap(TRX_NOT_SUPPORTED, ErrorCodes.VENDOR_ERROR);

        // Database-related errors 500 series
        putCodeMessage(DBE_NO_PARENT, "Database No Parent");
        putCodeMessage(DBE_CANNOT_DROP, "Database Cannot Drop");
        putCodeMessage(DBE_CANNOT_CREATE, "Database Cannot Create");
        putCodeMessage(DBE_CANNOT_READ, "Database Cannot Read");

        addFaultCodeToErrorCodeMap(DBE_NO_PARENT, ErrorCodes.INVALID_DATABASE);
        addFaultCodeToErrorCodeMap(DBE_CANNOT_DROP, ErrorCodes.VENDOR_ERROR);
        addFaultCodeToErrorCodeMap(DBE_CANNOT_CREATE, ErrorCodes.VENDOR_ERROR);
        addFaultCodeToErrorCodeMap(DBE_CANNOT_READ, ErrorCodes.VENDOR_ERROR);

        // Query-related errors 600 series
        putCodeMessage(QRY_NULL_RESULT, "Query Null Result");
        putCodeMessage(QRY_COMPILATION_ERROR, "Query Compilation Error");
        putCodeMessage(QRY_PROCESSING_ERROR, "Query Processing Error");
        putCodeMessage(QRY_NOT_SUPPORTED, "Query Not Supported");
        putCodeMessage(QRY_STYLE_NOT_FOUND, "Query Style Not Found");

        addFaultCodeToErrorCodeMap(QRY_NULL_RESULT, ErrorCodes.VENDOR_ERROR);
        addFaultCodeToErrorCodeMap(QRY_COMPILATION_ERROR, ErrorCodes.VENDOR_ERROR);
        addFaultCodeToErrorCodeMap(QRY_PROCESSING_ERROR, ErrorCodes.VENDOR_ERROR);
        addFaultCodeToErrorCodeMap(QRY_NOT_SUPPORTED, ErrorCodes.VENDOR_ERROR);
        addFaultCodeToErrorCodeMap(QRY_STYLE_NOT_FOUND, ErrorCodes.VENDOR_ERROR);

        // Security-related errors 700 series
        putCodeMessage(SEC_INVALID_USER, "Security Invalid User");
        putCodeMessage(SEC_INVALID_GROUP, "Security Invalid Group");
        putCodeMessage(SEC_INVALID_ACCESS, "Security Invalid Access");
        putCodeMessage(SEC_INVALID_CREDENTIALS, "Security Invalid Credentials");

        addFaultCodeToErrorCodeMap(SEC_INVALID_USER, ErrorCodes.PERMISSION_DENIED);
        addFaultCodeToErrorCodeMap(SEC_INVALID_GROUP, ErrorCodes.PERMISSION_DENIED);
        addFaultCodeToErrorCodeMap(SEC_INVALID_ACCESS, ErrorCodes.PERMISSION_DENIED);
        addFaultCodeToErrorCodeMap(SEC_INVALID_CREDENTIALS, ErrorCodes.PERMISSION_DENIED);

        // URI-related errors 800 series
        putCodeMessage(URI_EMPTY, "URI Empty");
        putCodeMessage(URI_NULL, "URI Null");
        putCodeMessage(URI_PARSE_ERROR, "URI Parse Error");

        addFaultCodeToErrorCodeMap(URI_EMPTY, ErrorCodes.INVALID_URI);
        addFaultCodeToErrorCodeMap(URI_NULL, ErrorCodes.INVALID_URI);
        addFaultCodeToErrorCodeMap(URI_PARSE_ERROR, ErrorCodes.INVALID_URI);

        // Java-related errors 2000 series
        putCodeMessage(JAVA_RUNTIME_ERROR, "Java Runtime Error");
    }

    private static void putCodeMessage(int code, String message) {
        faultMessages.put(new Integer(code), message);
    }

    private static void addFaultCodeToErrorCodeMap(int code, int errCode) {
        faultCodesToErrorCodesMap.put(new Integer(code), new Integer(errCode));
    }

    /**
     * getErrorCode returns the associated XML:DB error code for the
     * specified Xindice fault code
     *
     * @param faultCode The Xindice fault code
     * @return the associated XML:DB error code
     */
    public static int getErrorCode(int faultCode) {
        Object err = faultCodesToErrorCodesMap.get(new Integer(faultCode));
        if (err == null) {
            return ErrorCodes.UNKNOWN_ERROR;
        } else {
            return ((Integer) err).intValue();
        }
    }

    /**
     * getMessage returns a textual form for the specified fault code.
     *
     * @param code The Fault Code
     * @return It's textual form
     */
    public static String getMessage(int code) {
        String msg = (String) faultMessages.get(new Integer(code));
        return msg != null ? msg : "";
    }

    /**
     * createXMLDBException creates an XMLDBException instance based
     * on the specified Exception.  If the Exception is a DBException,
     * it will extract any important information from it (like fault
     * codes and messages)
     *
     * @param e The Exception to use
     * @return An XMLDBException instance
     */
    public static XMLDBException createXMLDBException(Exception e) {
        return createXMLDBException(null, e);
    }

    /**
     * createXMLDBException creates an XMLDBException instance based
     * on the specified Exception.  If the Exception is a DBException,
     * it will extract any important information from it (like fault
     * codes and messages)
     *
     * @param e The Exception to use
     * @param message The Message to use
     * @return An XMLDBException instance
     */
    public static XMLDBException createXMLDBException(String message, Exception e) {

        int faultCode = e instanceof RuntimeException ? JAVA_RUNTIME_ERROR : GEN_UNKNOWN;
        return createXMLDBException(faultCode, message, e);
    }

    public static XMLDBException createXMLDBException(int faultCode, String message, Exception e) {
        return createXMLDBException(ErrorCodes.VENDOR_ERROR, faultCode, message, e);
    }

    /**
     * Creates an XMLDBException instance based
     * on the specified fault code, message, and Exception.  If the Exception is a DBException,
     * it will extract any important information from it (like fault
     * codes and messages). If the exception is an instance of XindiceException,
     * the exception class name and message of any Throwable(s) available
     * via XindiceException.getCause will also be incorporated
     * into the message. If a chain of wrapped XindiceExceptions is available,
     * the chain will be followed incorporating the class name and message
     * at each level.
     *
     * @param errorCode error code for the XMLDBException
     * @param faultCode the fault code for the created exception
     * @param message message for the XMLDBException, or null to use message from e
     * @param e The Exception to use
     * @return An XMLDBException instance
     */
    public static XMLDBException createXMLDBException(int errorCode, int faultCode, String message, Exception e) {
        if (e instanceof XMLDBException) {
            return (XMLDBException) e;
        }

        if (e instanceof DBException) {
            faultCode = ((DBException) e).faultCode;
        }

        if (message == null) {
            message = e.getMessage();
        } else {
            message += ": " + e.getMessage();
        }

        // TODO: Mapping FaultCodes.COL_DOCUMENT_NOT_FOUND -> ErrorCodes.NO_SUCH_RESOURCE etc

        return new XMLDBException(errorCode, faultCode, message, e);
    }

    /**
     * getFaultCodeType examines the provided exception to determine
     * the general fault code that is associated with it.  General
     * fault codes are reduced from actual fault codes to be one of
     * the GEN_ prefixed fault code values.
     *
     * @param e The Exception to examine
     * @return The General Fault Code
     */
    public static int getFaultCodeType(Exception e) {
        int code = 0;
        if (e instanceof DBException) {
            code = ((DBException) e).faultCode;
        }

        // Strip it to the General series
        code = code % 100;
        // Narrow to a General value
        code = code - (code % 10);
        return code;
    }

    /**
     * getFaultCodeSeries examines the provided exception to
     * determine the fault code series that is associated with it.
     * Series are reduced from actual fault codes to be one of
     * the fault code prefixes (ex: COL, DB, SEC).
     *
     * @param e The Exception to examine
     * @return The Fault Code Series
     */
    public static int getFaultCodeSeries(Exception e) {
        int code = 0;
        if (e instanceof DBException) {
            code = ((DBException) e).faultCode;
        }

        // Strip it to the series
        code = code - (code % 100);
        return code;
    }

    /**
     * getFaultCode examines the provided exception to determine
     * the fault code that is associated with it.
     *
     * @param e The Exception to examine
     * @return The Fault Code
     */
    public static int getFaultCode(Exception e) {
        if (e instanceof DBException) {
            return ((DBException) e).faultCode;
        } else {
            return 0;
        }
    }

    /**
     * getFaultMessage examines the provided exception to determine
     * the fault message that is associated with it.
     *
     * @param e The Exception to examine
     * @return The Fault Message
     */
    public static String getFaultMessage(Exception e) {
        return getMessage(getFaultCode(e));
    }
}
