/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * $Id: NullWriter.java 541508 2007-05-25 01:54:12Z vgritsenko $
 */

package org.apache.xindice.core.meta.inline;

/**
 * Write metadata of length zero.  Handy for comparing performance
 * of the metadata-free database with a database using the metadata
 * machinery but containing no metadata.
 *
 * @version $Revision: 541508 $, $Date: 2007-05-24 21:54:12 -0400 (Thu, 24 May 2007) $
 */
public class NullWriter implements InlineMetaWriter {

    private static final byte[] NULL = new byte[0];

    /**
     * @see org.apache.xindice.core.meta.inline.InlineMetaWriter#getVersion()
     */
    public int getVersion() {
        return 0;
    }

    /**
     * @see org.apache.xindice.core.meta.inline.InlineMetaWriter#getMetadata(InlineMetaMap)
     */
    public byte[] getMetadata(InlineMetaMap map) throws InlineMetaException {
        return NULL;
    }
}
