/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * $Id: QueryResolver.java 541508 2007-05-25 01:54:12Z vgritsenko $
 */

package org.apache.xindice.core.query;

import org.apache.xindice.core.Collection;
import org.apache.xindice.core.data.Key;
import org.apache.xindice.core.data.NodeSet;
import org.apache.xindice.util.Configurable;
import org.apache.xindice.xml.NamespaceMap;

/**
 * QueryResolver is an interface that has to be implemented to actually
 * perfrom query resolution.  Xindice provides an XPathQueryResolver to
 * handle XPath queries against sets of Documents in a Collection.
 *
 * @version $Revision: 541508 $, $Date: 2007-05-24 21:54:12 -0400 (Thu, 24 May 2007) $
 */
public interface QueryResolver extends Configurable {

    /**
     * setQueryEngine hands a reference for the QueryEngine to the
     * Resolver.
     *
     * @param engine The QueryEngine
     */
    void setQueryEngine(QueryEngine engine);

    /**
     * getQueryStyle returns the Query style supported by this Resolver.
     *
     * @return The query style
     */
    String getQueryStyle();

    /**
     * compileQuery compiles a Query against the specified Collection
     * context and returns the compiled Query.  This DOES NOT actually
     * run the query, merely just parses it and primes any possible
     * Indexers that the query might need.
     *
     * @param context The Collection Context
     * @param query The Query
     * @param nsMap The namespace Map (if any)
     * @param keys The initial Key set to use (if any)
     * @return The compiled Query
     */
    Query compileQuery(Collection context, String query, NamespaceMap nsMap, Key[] keys) throws QueryException;

    /**
     * query compiles a Query against the specified Collection context
     * and returns the query results.
     *
     * @param context The Collection Context
     * @param query The Query
     * @param nsMap The namespace Map (if any)
     * @param keys The initial Key set to use (if any)
     * @return The resulting NodeSet
     */
    NodeSet query(Collection context, String query, NamespaceMap nsMap, Key[] keys) throws QueryException;

}
