/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * $Id: NodeTermDocs.java 584476 2007-10-14 02:41:50Z natalia $
 */

package org.apache.xindice.core.query.ftsearch;

import org.apache.lucene.index.TermDocs;
import org.apache.lucene.index.Term;
import org.apache.lucene.index.TermEnum;

import java.util.ArrayList;
import java.util.Iterator;
import java.util.Map;
import java.util.List;

/**
 * TermDocs for searching over DOM nodes in memory
 *
 * @version $Revision: 584476 $, $Date: 2007-10-13 22:41:50 -0400 (Sat, 13 Oct 2007) $
 */
public class NodeTermDocs implements TermDocs {
    protected int num;
    protected ArrayList[] nodes;
    protected Map termMap;
    protected int[] freqs;
    private boolean init;

    public NodeTermDocs(NodeReader reader) {
        nodes = reader.getNodes();
        termMap = reader.getTermMap();

        freqs = new int[nodes.length];
    }

    public void seek(Term term) {
        List docs = (List) termMap.get(term.text());
        if (docs != null) {
            for (Iterator i = docs.iterator(); i.hasNext(); ) {
                int idx = ((Integer) i.next()).intValue();
                freqs[idx]++;
            }
        }
    }

    public void seek(TermEnum termEnum)  {
        seek(termEnum.term());
    }

    public int doc() {
        return num;
    }

    public int freq() {
        return freqs[num];
    }

    public boolean next() {
        if (!init) {
            init = true;
            num = 0;
        } else {
            num++;
        }

        while(num < nodes.length && freqs[num] == 0) {
            num++;
        }

        return num < nodes.length;
    }

    public int read(int[] docs, int[] freqs) {
        int count = 0;
        for (int i = 0; i < docs.length && num < nodes.length; i++, num++) {
            if (this.freqs[num] > 0) {
                freqs[count] = this.freqs[num];
                docs[count] = num;
                count++;
            }
        }

        return count;
    }

    public boolean skipTo(int target) {
        num = target;
        return num < nodes.length;
    }

    /**
     * Not applicable
     */
    public void close() {
    }
}
