/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * $Id: NodeTermEnum.java 584476 2007-10-14 02:41:50Z natalia $
 */

package org.apache.xindice.core.query.ftsearch;

import org.apache.lucene.index.TermEnum;
import org.apache.lucene.index.Term;

import java.util.Iterator;
import java.util.SortedMap;
import java.util.HashSet;
import java.util.List;

/**
 * Ordered set of terms used by NodeReader.
 *
 * @version $Revision: 584476 $, $Date: 2007-10-13 22:41:50 -0400 (Sat, 13 Oct 2007) $
 */
public class NodeTermEnum extends TermEnum {
    // map that backs this enumeration
    private SortedMap termMap;

    private Iterator iterator;
    
    // value of the current term
    private String curTerm;

    public NodeTermEnum(SortedMap termMap) {
        this.termMap = termMap;
        iterator = this.termMap.keySet().iterator();
        if (iterator.hasNext()) {
            curTerm = (String) iterator.next();
        }
    }

    public NodeTermEnum(SortedMap termMap, Term t) {
        this(termMap.tailMap(t.text()));
    }

    public boolean next() {
        if (iterator.hasNext()) {
            curTerm = (String) iterator.next();
            return true;
        }

        return false;
    }

    public Term term() {
        if (curTerm != null) {
            return new Term("", curTerm);
        }

        return null;
    }

    public int docFreq() {
        List docs = (List) termMap.get(curTerm);

        HashSet set = new HashSet();
        set.addAll(docs);
        return set.size();
    }

    /**
     * Not applicable
     */
    public void close() {
    }
}
