/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * $Id: XObjectImpl.java 541508 2007-05-25 01:54:12Z vgritsenko $
 */

package org.apache.xindice.core.xupdate;

import org.apache.xpath.objects.XObject;

import org.w3c.dom.DocumentFragment;
import org.w3c.dom.NodeList;

/**
 * Wrapper for Xalan XObject
 *
 * @version $Revision: 541508 $, $Date: 2007-05-24 21:54:12 -0400 (Thu, 24 May 2007) $
 */
public final class XObjectImpl implements org.xmldb.common.xml.queries.XObject {

    private XObject _xobj = null;

    /**
     * Creates a new XObject to wrap a Xalan XObject
     *
     * @param xobj xalan's XObject that should be wrapped.
     * @exception IllegalArgumentException If the given XObject was null.
     */
    public XObjectImpl(XObject xobj) throws IllegalArgumentException {
        if (xobj == null) {
            throw new IllegalArgumentException("XalanXObject(): Argument was null!");
        }
        _xobj = xobj;
    }

    public int getType() {
        return _xobj.getType();
    }

    public boolean bool() throws Exception {
        return _xobj.bool();
    }

    public double num() throws Exception {
        return _xobj.num();
    }

    public String str() {
        return _xobj.str();
    }

    // this works like the old xalan1 nodset()
    public NodeList nodeset() throws Exception {
        return _xobj.nodelist();
    }

    public DocumentFragment rtree() {
        return _xobj.rtree();
    }
}
