/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * $Id: ByteArrayInput.java 571951 2007-09-02 10:53:51Z vgritsenko $
 */

package org.apache.xindice.util;

import java.io.ByteArrayInputStream;
import java.io.IOException;
import java.io.InputStream;

/**
 * ByteArrayInput is a wrapper around ByteArrayInputStream that allows read
 * access to the current position pointer.
 *
 * @version $Revision: 571951 $, $Date: 2007-09-02 06:53:51 -0400 (Sun, 02 Sep 2007) $
 */
public final class ByteArrayInput extends ByteArrayInputStream {

    public ByteArrayInput(byte[] buf) {
        super(buf);
    }

    public ByteArrayInput(byte[] buf, int pos, int length) {
        super(buf, pos, length);
    }

    /**
     * getPos returns the current read position in the array.  This value is not
     * a relative offset from the start of the original stream, but an absolute
     * position in the array itself.
     *
     * @return The Array Position
     */
    public int getPos() {
        return pos;
    }

    /**
     * setPos sets the current read position in the array.  This value is not a
     * relative offset from the start of the original stream, but an absolute
     * position in the array itself.  As such, you can seek back to a position
     * before the originating position of the InputStream.
     *
     * @param pos The Array Position
     * @throws IOException if the position is out of range
     */
    public void setPos(int pos) throws IOException {
        if (pos >= 0 && pos < buf.length) {
            this.pos = pos;
        } else {
            throw new IOException("setPos position out of bounds");
        }
    }

    /**
     * getInputStream returns a newly created ByteArrayInput based on this
     * instance's data and current position.  This is a good alternative to
     * mark and reset because it allows multiple threads to safely access
     * the byte array at one time.
     *
     * @return The New ByteArrayInput object
     */
    public InputStream getInputStream() {
        return new ByteArrayInput(buf, pos, count);
    }
}
