/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * $Id: ContentResourceViewer.java 541515 2007-05-25 02:45:06Z vgritsenko $
 */

package org.apache.xindice.webadmin.viewer.components;

import java.io.IOException;

import javax.servlet.ServletException;
import javax.servlet.ServletOutputStream;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.w3c.dom.Document;

import org.apache.xindice.core.Collection;
import org.apache.xindice.core.DBException;
import org.apache.xindice.core.data.Entry;
import org.apache.xindice.webadmin.viewer.*;
import org.apache.xindice.webadmin.viewer.HtmlViewerComponent;
import org.apache.xindice.xml.Xml2HtmlWriter;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

/**
 * Xindice Html Contents Viewer for Resources
 *
 * @author <a href="mailto:jmetzner@apache.org">Jan Metzner</a>
 * @version $Revision: 541515 $, $Date: 2007-05-24 22:45:06 -0400 (Thu, 24 May 2007) $
 */
public class ContentResourceViewer extends HtmlViewerComponent implements HtmlResourceViewer {

    private static final Log log = LogFactory.getLog(ContentResourceViewer.class);

    public void execute(HttpServletRequest req, HttpServletResponse res, Collection col, String name)
            throws ServletException, IOException {

        String path = col.getCanonicalName() + "/" + name;
        String title = "Document " + path;

        Entry resource;
        try {
            resource = col.getEntry(name);
        } catch (DBException e) {
            log.error(e);
            throw new ServletException(e);
        }

        ServletOutputStream output = startViewer(title, path, res);
        printStartTable(title, output);
        printStartSingleTableBox(output);
        output.print("<a href=\"./?viewer=default\">up to parent collection</a>");
        printEndSingleTableBox(output);
        printStartSingleTableBox(output);
        if (resource.getEntryType() == Entry.DOCUMENT) {
            Xml2HtmlWriter.write((Document) resource.getValue(), output);
        } else {
            output.print("binary resource <a href=\"./");
            output.print(name);
            output.print("\">view content</a>");
        }
        printEndSingleTableBox(output);
        printEndTable(output);
        finishViewer(output);
    }

    protected String getName() {
        return "content";
    }
}
