/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * $Id: DeleteResourceViewer.java 541515 2007-05-25 02:45:06Z vgritsenko $
 */

package org.apache.xindice.webadmin.viewer.components;

import java.io.IOException;

import javax.servlet.ServletException;
import javax.servlet.ServletOutputStream;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.xindice.core.Collection;
import org.apache.xindice.core.DBException;
import org.apache.xindice.webadmin.viewer.HtmlViewerComponent;
import org.apache.xindice.webadmin.viewer.HtmlResourceViewer;
import org.apache.commons.logging.LogFactory;
import org.apache.commons.logging.Log;

/**
 * Xindice Html Viewer for deleting resources.
 *
 * @author <a href="mailto:jmetzner@apache.org">Jan Metzner</a>
 * @version $Revision: 541515 $, $Date: 2007-05-24 22:45:06 -0400 (Thu, 24 May 2007) $
 */
public class DeleteResourceViewer extends HtmlViewerComponent implements HtmlResourceViewer {
    private static final Log log = LogFactory.getLog(DeleteResourceViewer.class);

    public void execute(HttpServletRequest req, HttpServletResponse res, Collection col, String resourceName)
            throws ServletException, IOException {

        String path = col.getCanonicalName() + "/" + resourceName;
        String title = "Delete Document " + path;

        String action = req.getParameter("action");
        String redirect = req.getParameter("redirect");
        if (redirect == null) {
            redirect = "";
        }

        if (!"yes".equals(action)) { // ask confirmation
            ServletOutputStream output = startViewer(title, path, res);
            printStartTable(title, output);
            printStartSingleTableBox(output);
            output.print("<a href=\"./?viewer=default\">up to parent collection</a>");
            printEndSingleTableBox(output);
            printStartSingleTableBox(output);
            output.print("Do you really want to delete ");
            output.print(resourceName);
            output.print("? <a href=\"javascript:history.back()\">no</a> ");
            output.print("<a href=\"?viewer=delete&action=yes&redirect=");
            output.print(redirect);
            output.print("\">yes</a>");
            printEndSingleTableBox(output);
            printEndTable(output);
            finishViewer(output);
        } else {
            try {
                // delete resource
                col.remove(resourceName);

                // display output or redirect
                if (redirect.length() > 0) {
                    res.sendRedirect(redirect);
                } else {
                    ServletOutputStream output = startViewer(title, path, res);
                    printStartTable(title, output);
                    printStartSingleTableBox(output);
                    output.print("<a href=\"./?viewer=default\">up to parent collection</a>");
                    printEndSingleTableBox(output);
                    printStartSingleTableBox(output);
                    output.print("<b>Document ");
                    output.print(resourceName);
                    output.print(" deleted! </b>");
                    printEndSingleTableBox(output);
                    printEndTable(output);
                    finishViewer(output);
                }
            } catch (DBException e) {
                log.error(e);
                ServletOutputStream output = startViewer(title, path, res);
                printStartTable(title, output);
                printStartSingleTableBox(output);
                output.print("<a href=\"./?viewer=default\">up to parent collection</a>");
                printEndSingleTableBox(output);
                printStartSingleTableBox(output);
                output.print("<b>Cannot delete ");
                output.print(resourceName);
                output.print(": ");
                output.print(e.getMessage());
                printEndSingleTableBox(output);
                printEndTable(output);
                finishViewer(output);
            }
        }

    }

    protected String getName() {
        return "delete";
    }

}
