/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * $Id: ListDatabaseViewer.java 541515 2007-05-25 02:45:06Z vgritsenko $
 */

package org.apache.xindice.webadmin.viewer.components;

import org.apache.xindice.webadmin.viewer.HtmlViewerComponent;
import org.apache.xindice.webadmin.viewer.HtmlDatabaseViewer;
import org.apache.xindice.core.Database;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.ServletException;
import javax.servlet.ServletOutputStream;
import java.io.IOException;

/**
 * Xindice Html Viewer for database listings.
 *
 * @version $Revision: 541515 $, $Date: 2007-05-24 22:45:06 -0400 (Thu, 24 May 2007) $
 */
public class ListDatabaseViewer extends HtmlViewerComponent implements HtmlDatabaseViewer {

    public void execute(HttpServletRequest req, HttpServletResponse res) throws ServletException, IOException {

        String[] databases = Database.listDatabases();

        String path = "/";
        String title = "List databases";

        ListDatabaseViewer.TableRow row = new ListDatabaseViewer.TableRow();
        ServletOutputStream output = startViewer(title, path, res);
        printStartTable(row.getTitles(), output);

        for (int i = 0; i < databases.length; i++) {
            boolean metaEnabled = Database.getDatabase(databases[i]).isMetaEnabled();
            String dbRoot = Database.getDatabase(databases[i]).getCollectionRoot().getCanonicalPath();
            printTableRow(row.getDatabase(databases[i], metaEnabled, dbRoot), output);
        }

        printEndTable(output);
        finishViewer(output);
    }

    protected String getName() {
        return "list";
    }

    // TableRow Inner Class
    protected class TableRow {

        protected final String[] titles = {"Name", "Type", "Meta-enabled", "DB root"};

        protected String[] content;

        TableRow() {
            content = new String[titles.length];
            reset();
        }

        protected String[] getTitles() {
            return titles;
        }

        protected void reset() {
            for (int i = 0; i < content.length; i++) {
                content[i] = null;
            }
        }

        protected String[] getDatabase(String name, boolean metaEnabled, String dbRoot) {
            reset();
            content[0] = createLink(name + "/?viewer=list", name);
            content[1] = "database";
            content[2] = Boolean.toString(metaEnabled);
            content[3] = dbRoot;
            return content;
        }

        protected String createLink(String link, String name) {
            return "<a href=\"" + link + "\">" + name + "</a>";
        }
    }
}
