/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.xindice.webadmin.webdav.components.props;

import org.apache.xindice.core.Collection;
import org.apache.xindice.core.data.Entry;
import org.apache.xindice.webadmin.PartialResponse;
import org.apache.xindice.util.StringUtilities;

/**
 * DisplayName creates a response node that contains resource name, which is
 * a collection name for collections and key for collection entries.
 * <br/><br/>
 * Example:
 * <pre>
 * &lt;displayname&gt;
 *     System
 * &lt;/displayname&gt;
 * </pre>
 *
 * @version $Revision: 541515 $, $Date: 2007-05-24 22:45:06 -0400 (Thu, 24 May 2007) $
 */
public class DisplayName implements DAVProperty {
    private static final String DISPLAY_NAME = "displayname";

    public String getName() {
        return DISPLAY_NAME;
    }

    public PartialResponse.Content getRootProperty() {
        return new PartialResponse.Content(DISPLAY_NAME, "/");
    }

    public PartialResponse.Content getProperty(Collection col) {
        return new PartialResponse.Content(DISPLAY_NAME, StringUtilities.escapeXml(col.getName()));
    }

    public PartialResponse.Content getProperty(Entry entry) {
        return new PartialResponse.Content(DISPLAY_NAME, StringUtilities.escapeXml(entry.getKey().toString()));
    }

}
