/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * $Id: CompressedDocument.java 541508 2007-05-25 01:54:12Z vgritsenko $
 */

package org.apache.xindice.xml.dom;

import org.apache.xindice.xml.SymbolTable;

import org.w3c.dom.DOMException;
import org.w3c.dom.Document;
import org.w3c.dom.Node;

/**
 * CompressedDocument exposes the Document's SymbolTable.
 *
 * @version $Revision: 541508 $, $Date: 2007-05-24 21:54:12 -0400 (Thu, 24 May 2007) $
 */
public interface CompressedDocument extends CompressedNode, Document {

    /**
     * getSymbols returns the Symbol table for this Document.  A new
     * Document may not have a Symbol table as Symbol tables only come
     * into play when a Document has been compressed or decompressed.
     *
     * @return The Symbol table
     */
    SymbolTable getSymbols();

    /**
     * setSymbols sets the Symbol table for this Document.  Setting
     * the Symbol table for a Document that already has a Symbol table
     * could be VERY BAD.  Generally, an implementation should throw
     * a DOMException if an attempt is made to reassign a Symbol table.
     *
     * @param symbols The Symbol table
     * @throws DOMException if an exception occurs
     */
    void setSymbols(SymbolTable symbols) throws DOMException;

    /**
     * getNodeAtPos returns the Node that exists at the specified
     * byte data  position in the compressed stream.  This method
     * should only be used on an unmodified Document as the
     * underlying compressed stream of a document will become
     * invalid as the Document is modified.
     *
     * @param pos The compressed stream position
     * @return The Node (or null if not found)
     */
    Node getNodeAtPos(int pos);
}
