/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * $Id: DOMConfigurationImpl.java 541508 2007-05-25 01:54:12Z vgritsenko $
 */

package org.apache.xindice.xml.dom;

import org.w3c.dom.DOMConfiguration;
import org.w3c.dom.DOMException;
import org.w3c.dom.DOMStringList;

import java.util.HashMap;
import java.util.Collections;
import java.util.Map;

/**
 *
 * @version $Revision: 541508 $, $Date: 2007-05-24 21:54:12 -0400 (Thu, 24 May 2007) $
 */
public class DOMConfigurationImpl implements DOMConfiguration {

    private static final DOMStringList NAMES = new DOMStringListImpl();

    private Map config = Collections.synchronizedMap(new HashMap());

    DOMConfigurationImpl() {
        config.put("canonical-form", null);
        config.put("cdata-sections", null);
        config.put("check-character-normalization", null);
        config.put("comments", null);
        config.put("datatype-normalization", null);
        config.put("element-content-whitespace", null);
        config.put("entities", null);
        config.put("error-handler", null);
        config.put("infoset", null);
        config.put("namespaces", null);
        config.put("namespace-declarations", null);
        config.put("normalize-characters", null);
        config.put("schema-location", null);
        config.put("schema-type", null);
        config.put("split-cdata-sections", null);
        config.put("validate", null);
        config.put("validate-if-schema", null);
        config.put("well-formed", null);
    }

    public void setParameter(String name, Object value) throws DOMException {
        if (!config.containsKey(name)) {
            throw new DOMException(DOMException.NOT_FOUND_ERR, "Parameter " + name + " is not recognized");
        }
    }

    public Object getParameter(String name) throws DOMException {
        if (!config.containsKey(name)) {
            throw new DOMException(DOMException.NOT_FOUND_ERR, "Parameter " + name + " is not recognized");
        }

        return config.get(name);
    }

    public boolean canSetParameter(String name, Object value) {
        return false;
    }

    public DOMStringList getParameterNames() {
        return NAMES;
    }
}
