/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.xindice.webadmin;

import junit.framework.TestCase;
import org.apache.xindice.core.Database;
import org.apache.xindice.core.DatabaseTest;
import org.apache.xindice.core.Collection;
import org.apache.xindice.util.Configuration;
import org.apache.xindice.xml.dom.DOMParser;


public class LocationTest extends TestCase {
    private Database db;
    private Collection collection;

    public void setUp() throws Exception {
        String name = getClass().getName();
        db = Database.getDatabase(new Configuration(DOMParser.toDocument(DatabaseTest.DATABASE)));
        collection = db.createCollection(name, new Configuration(
                DOMParser.toDocument(
                        "<collection compressed=\"true\" name=\"" + name + "\" inline-metadata=\"true\">" +
                        "<filer class=\"org.apache.xindice.core.filer.BTreeFiler\" />" +
                        "</collection>"), false
        ));
    }

    public void tearDown() throws Exception {
        db.dropCollection(collection);
        db.close();
    }

    public void testRootLocation() throws Exception {
        Location location = new Location("");
        assertTrue(location.isRoot());
        assertNull(location.getCollection());
        assertNull(location.getName());
    }

    public void testDbLocation() throws Exception {
        Location location = new Location(db.getCanonicalName());
        assertFalse(location.isRoot());
        assertEquals(location.getCollection(), db);
        assertNull(location.getName());
    }

    public void testCollectionNoResourceLocation() throws Exception {
        Location location = new Location(collection.getCanonicalName());
        assertFalse(location.isRoot());
        assertEquals(location.getCollection(), collection);
        assertNull(location.getName());
    }

    public void testCollectionResourceLocation() throws Exception {
        Location location = new Location(collection.getCanonicalDocumentName("doesnotexist"));
        assertFalse(location.isRoot());
        assertEquals(location.getCollection(), collection);
        assertEquals(location.getName(), "doesnotexist");
    }

    public void testNoCollectionLocation() throws Exception {
        Location location = new Location(collection.getCanonicalName() + "/doesnotexist/doesnotexist1");
        assertFalse(location.isRoot());
        assertNull(location.getCollection());
        assertNull(location.getName());
    }
}
