/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * $Id: DocumentTest.java 518749 2007-03-15 20:38:08Z vgritsenko $
 */

package org.apache.xindice.xml.dom;

import org.w3c.dom.NamedNodeMap;
import org.w3c.dom.Node;

/**
 * Tests NodeImpl class
 *
 * @version $Revision: 518749 $, $Date: 2007-03-15 16:38:08 -0400 (Thu, 15 Mar 2007) $
 */
public class DocumentTest extends DOMTestCase {

    public String getXml() {
        return
            "<?xml version='1.0' encoding='UTF-8'?>" +
            "<a xmlns:name='http://apache.org'>" +
                "<b/>" +
                "<name:c attr1='a' attr2='b'>" +
                    "<d attr3='c' attr4='d'/>" +
                "</name:c>" +
                "<c attr1='a' attr2='b'>" +
                    "<d attr3='c' attr4='d'/>" +
                "</c>" +
            "</a>";
    }

    public void testRenameNode() throws Exception {
        Node node1 = doc.getFirstChild().getFirstChild().getNextSibling();

        node1 = ((DocumentImpl) doc).renameNode(node1, "http://xindice.org", "new:name");
        assertEquals(node1.getNodeName(), "new:name");
        assertEquals(node1.getNamespaceURI(), "http://xindice.org");

        node1 = ((DocumentImpl) doc).renameNode(node1, "", "name");
        assertEquals(node1.getNodeName(), "name");
        assertEquals(node1.getNamespaceURI(), null);

        NamedNodeMap attrs = doc.getFirstChild().getFirstChild().getNextSibling().getAttributes();
        node1 = attrs.getNamedItem("attr1");
        node1 = ((DocumentImpl) doc).renameNode(node1, "http://xindice.org", "new:attr4");
        assertEquals(node1.getNodeName(), "new:attr4");
        assertEquals(node1.getNamespaceURI(), "http://xindice.org");
    }
}
